==> jar-runner-maven-plugin-0.9.5-test-sources.jar: META-INF/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

<a name="0.9.5"></a>

## [0.9.5](https://github.com/lars-sh/jar-runner-maven-plugin/compare/570557e457bdc5bead85ff7c0df4d1de676a24e4...8d8ce3fda280a6abeee3035edc74829ecc521113) (2019-07-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.5/jar)

* Add user argument `runAsync` to start application detached
* Change exit code handling, now inheriting the applications exit code

<a name="0.9.4"></a>

## [0.9.4](https://github.com/lars-sh/jar-runner-maven-plugin/compare/a8b47e13939b28ec35c97584bcb7ca892bca6346...570557e457bdc5bead85ff7c0df4d1de676a24e4) (2019-05-21)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.4/jar)

* Add user arguments to handle repositories

<a name="0.9.3"></a>

## [0.9.3](https://github.com/lars-sh/jar-runner-maven-plugin/compare/323ffc298bfae6442bc2058de650c16dc99b7fcf...a8b47e13939b28ec35c97584bcb7ca892bca6346) (2019-05-15)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.3/jar)

* Fix plugin-own dependency hierarchy

<a name="0.9.2"></a>

## [0.9.2](https://github.com/lars-sh/jar-runner-maven-plugin/compare/e09a123af35b8d6af6ebf03a0e4a010ce32a10af...323ffc298bfae6442bc2058de650c16dc99b7fcf) (2019-05-06)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.2/jar)

### Changed
* Use Maven version prerequisite

### Fixed
* Support for Maven versions unequal to 3.6.0

<a name="0.9.1"></a>

## [0.9.1](https://github.com/lars-sh/jar-runner-maven-plugin/commit/e09a123af35b8d6af6ebf03a0e4a010ce32a10af) (2018-12-12)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.1/jar)

* Initial release

==> jar-runner-maven-plugin-0.9.6-test-sources.jar: META-INF/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

<a name="0.9.6"></a>

## [0.9.6](https://github.com/lars-sh/jar-runner-maven-plugin/compare/570557e457bdc5bead85ff7c0df4d1de676a24e4...a24df52e7d034267d6059f5cfe324a0365184d6f) (2021-12-27)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.6/jar)

* Log executed command to simplify finding problems
* `,` and `],[` can be used to separate multiple arguments from each other. Instead `[,]` can be used to represent an actual comma character. Before arguments inside lists were not able to contain comma characters.

<a name="0.9.5"></a>

## [0.9.5](https://github.com/lars-sh/jar-runner-maven-plugin/compare/570557e457bdc5bead85ff7c0df4d1de676a24e4...8d8ce3fda280a6abeee3035edc74829ecc521113) (2019-07-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.5/jar)

* Add user argument `runAsync` to start application detached
* Change exit code handling, now inheriting the applications exit code

<a name="0.9.4"></a>

## [0.9.4](https://github.com/lars-sh/jar-runner-maven-plugin/compare/a8b47e13939b28ec35c97584bcb7ca892bca6346...570557e457bdc5bead85ff7c0df4d1de676a24e4) (2019-05-21)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.4/jar)

* Add user arguments to handle repositories

<a name="0.9.3"></a>

## [0.9.3](https://github.com/lars-sh/jar-runner-maven-plugin/compare/323ffc298bfae6442bc2058de650c16dc99b7fcf...a8b47e13939b28ec35c97584bcb7ca892bca6346) (2019-05-15)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.3/jar)

* Fix plugin-own dependency hierarchy

<a name="0.9.2"></a>

## [0.9.2](https://github.com/lars-sh/jar-runner-maven-plugin/compare/e09a123af35b8d6af6ebf03a0e4a010ce32a10af...323ffc298bfae6442bc2058de650c16dc99b7fcf) (2019-05-06)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.2/jar)

### Changed
* Use Maven version prerequisite

### Fixed
* Support for Maven versions unequal to 3.6.0

<a name="0.9.1"></a>

## [0.9.1](https://github.com/lars-sh/jar-runner-maven-plugin/commit/e09a123af35b8d6af6ebf03a0e4a010ce32a10af) (2018-12-12)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/jar-runner-maven-plugin/0.9.1/jar)

* Initial release
